@@ -15,14 +15,13 @@ from ...interfaces import vtkbase as VTKInfo
 
 @pytest.mark.skipif(VTKInfo.no_tvtk(), reason="tvtk is not installed")
 def test_ident_distances(tmpdir):
-    tempdir = str(tmpdir)
-    os.chdir(tempdir)
+    tmpdir.chdir()
 
     in_surf = example_data('surf01.vtk')
     dist_ident = m.ComputeMeshWarp()
     dist_ident.inputs.surface1 = in_surf
     dist_ident.inputs.surface2 = in_surf
-    dist_ident.inputs.out_file = os.path.join(tempdir, 'distance.npy')
+    dist_ident.inputs.out_file = tmpdir.join('distance.npy')
     res = dist_ident.run()
     assert res.outputs.distance == 0.0
 
@@ -33,11 +32,11 @@ def test_ident_distances(tmpdir):
 
 @pytest.mark.skipif(VTKInfo.no_tvtk(), reason="tvtk is not installed")
 def test_trans_distances(tmpdir):
-    tempdir = str(tmpdir)
+    tempdir = tmpdir.strpath
     from ...interfaces.vtkbase import tvtk
 
     in_surf = example_data('surf01.vtk')
-    warped_surf = os.path.join(tempdir, 'warped.vtk')
+    warped_surf = tmpdir.join('warped.vtk')
 
     inc = np.array([0.7, 0.3, -0.2])
 
@@ -53,7 +52,7 @@ def test_trans_distances(tmpdir):
     dist = m.ComputeMeshWarp()
     dist.inputs.surface1 = in_surf
     dist.inputs.surface2 = warped_surf
-    dist.inputs.out_file = os.path.join(tempdir, 'distance.npy')
+    dist.inputs.out_file = tmpdir.join('distance.npy')
     res = dist.run()
     assert np.allclose(res.outputs.distance, np.linalg.norm(inc), 4)
     dist.inputs.weighting = 'area'
@@ -63,14 +62,14 @@ def test_trans_distances(tmpdir):
 
 @pytest.mark.skipif(VTKInfo.no_tvtk(), reason="tvtk is not installed")
 def test_warppoints(tmpdir):
-    os.chdir(str(tmpdir))
+    tmpdir.chdir()
 
     # TODO: include regression tests for when tvtk is installed
 
 
 @pytest.mark.skipif(VTKInfo.no_tvtk(), reason="tvtk is not installed")
 def test_meshwarpmaths(tmpdir):
-    os.chdir(str(tmpdir))
+    tmpdir.chdir()
 
     # TODO: include regression tests for when tvtk is installed
 
