@@ -18,7 +18,9 @@ from .utils import (AvScale, Smooth, Merge, ExtractROI, Split, ImageMaths, Image
                     PlotTimeSeries, PlotMotionParams, ConvertXFM,
                     SwapDimensions, PowerSpectrum, Reorient2Std,
                     Complex, InvWarp, WarpUtils, ConvertWarp, WarpPoints,
-                    WarpPointsToStd, RobustFOV, CopyGeom, MotionOutliers)
+                    WarpPointsToStd, WarpPointsFromStd, RobustFOV,
+                    CopyGeom, MotionOutliers)
+
 from .epi import (PrepareFieldmap, TOPUP, ApplyTOPUP, Eddy, EPIDeWarp,
                   SigLoss, EddyCorrect, EpiReg)
 from .dti import (BEDPOSTX, XFibres, DTIFit,
@@ -33,3 +35,4 @@ from .maths import (ChangeDataType, Threshold, MeanImage, ApplyMask,
 from .possum import B0Calc
 from .fix import (AccuracyTester, Classifier, Cleaner, FeatureExtractor,
                   Training, TrainingSetCreator)
+from .aroma import ICA_AROMA
