@@ -71,7 +71,7 @@ class PrepareFieldmap(FSLCommand):
     >>> prepare.inputs.in_phase = "phase.nii"
     >>> prepare.inputs.in_magnitude = "magnitude.nii"
     >>> prepare.inputs.output_type = "NIFTI_GZ"
-    >>> prepare.cmdline # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> prepare.cmdline # doctest: +ELLIPSIS
     'fsl_prepare_fieldmap SIEMENS phase.nii magnitude.nii \
 .../phase_fslprepared.nii.gz 2.460000'
     >>> res = prepare.run() # doctest: +SKIP
@@ -143,6 +143,9 @@ class TOPUPInputSpec(FSLCommandInputSpec):
     out_warp_prefix = traits.Str("warpfield", argstr='--dfout=%s', hash_files=False,
                                  desc='prefix for the warpfield images (in mm)',
                                  usedefault=True)
+    out_mat_prefix = traits.Str("xfm", argstr='--rbmout=%s', hash_files=False,
+                                desc='prefix for the realignment matrices',
+                                usedefault=True)
     out_jac_prefix = traits.Str("jac", argstr='--jacout=%s',
                                  hash_files=False,
                                  desc='prefix for the warpfield images',
@@ -221,6 +224,7 @@ class TOPUPOutputSpec(TraitedSpec):
     out_field = File(desc='name of image file with field (Hz)')
     out_warps = traits.List(File(exists=True), desc='warpfield images')
     out_jacs = traits.List(File(exists=True), desc='Jacobian images')
+    out_mats = traits.List(File(exists=True), desc='realignment matrices')
     out_corrected = File(desc='name of 4D image file with unwarped images')
     out_logfile = File(desc='name of log-file')
 
@@ -243,11 +247,11 @@ class TOPUP(FSLCommand):
     >>> topup.inputs.in_file = "b0_b0rev.nii"
     >>> topup.inputs.encoding_file = "topup_encoding.txt"
     >>> topup.inputs.output_type = "NIFTI_GZ"
-    >>> topup.cmdline # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> topup.cmdline # doctest: +ELLIPSIS
     'topup --config=b02b0.cnf --datain=topup_encoding.txt \
 --imain=b0_b0rev.nii --out=b0_b0rev_base --iout=b0_b0rev_corrected.nii.gz \
 --fout=b0_b0rev_field.nii.gz --jacout=jac --logout=b0_b0rev_topup.log \
---dfout=warpfield'
+--rbmout=xfm --dfout=warpfield'
     >>> res = topup.run() # doctest: +SKIP
 
     """
@@ -289,6 +293,9 @@ class TOPUP(FSLCommand):
         outputs['out_jacs'] = [
             fmt(prefix=self.inputs.out_jac_prefix, i=i, ext=ext)
             for i in range(1, n_vols + 1)]
+        outputs['out_mats'] = [
+            fmt(prefix=self.inputs.out_mat_prefix, i=i, ext=".mat")
+            for i in range(1, n_vols + 1)]
 
         if isdefined(self.inputs.encoding_direction):
             outputs['out_enc_file'] = self._get_encfilename()
@@ -382,7 +389,7 @@ class ApplyTOPUP(FSLCommand):
     >>> applytopup.inputs.in_topup_fieldcoef = "topup_fieldcoef.nii.gz"
     >>> applytopup.inputs.in_topup_movpar = "topup_movpar.txt"
     >>> applytopup.inputs.output_type = "NIFTI_GZ"
-    >>> applytopup.cmdline # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> applytopup.cmdline # doctest: +ELLIPSIS
     'applytopup --datain=topup_encoding.txt --imain=epi.nii,epi_rev.nii \
 --inindex=1,2 --topup=topup --out=epi_corrected.nii.gz'
     >>> res = applytopup.run() # doctest: +SKIP
@@ -538,12 +545,12 @@ class Eddy(FSLCommand):
     >>> eddy.inputs.in_bvec  = 'bvecs.scheme'
     >>> eddy.inputs.in_bval  = 'bvals.scheme'
     >>> eddy.inputs.use_cuda = True
-    >>> eddy.cmdline # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> eddy.cmdline # doctest: +ELLIPSIS
     'eddy_cuda --acqp=epi_acqp.txt --bvals=bvals.scheme --bvecs=bvecs.scheme \
 --imain=epi.nii --index=epi_index.txt --mask=epi_mask.nii \
 --out=.../eddy_corrected'
     >>> eddy.inputs.use_cuda = False
-    >>> eddy.cmdline # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> eddy.cmdline # doctest: +ELLIPSIS
     'eddy_openmp --acqp=epi_acqp.txt --bvals=bvals.scheme \
 --bvecs=bvecs.scheme --imain=epi.nii --index=epi_index.txt \
 --mask=epi_mask.nii --out=.../eddy_corrected'
@@ -585,7 +592,7 @@ class Eddy(FSLCommand):
         cmd = self._cmd
         if all((FSLDIR != '',
                 cmd == 'eddy_openmp',
-                not os.path.exists(os.path.join(FSLDIR, cmd)))):
+                not os.path.exists(os.path.join(FSLDIR, 'bin', cmd)))):
             self._cmd = 'eddy'
         runtime = super(Eddy, self)._run_interface(runtime)
 
@@ -672,7 +679,7 @@ class SigLoss(FSLCommand):
     >>> sigloss.inputs.in_file = "phase.nii"
     >>> sigloss.inputs.echo_time = 0.03
     >>> sigloss.inputs.output_type = "NIFTI_GZ"
-    >>> sigloss.cmdline # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> sigloss.cmdline # doctest: +ELLIPSIS
     'sigloss --te=0.030000 -i phase.nii -s .../phase_sigloss.nii.gz'
     >>> res = sigloss.run() # doctest: +SKIP
 
@@ -777,7 +784,7 @@ class EpiReg(FSLCommand):
     >>> epireg.inputs.fmapmagbrain='fieldmap_mag_brain.nii'
     >>> epireg.inputs.echospacing=0.00067
     >>> epireg.inputs.pedir='y'
-    >>> epireg.cmdline # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> epireg.cmdline # doctest: +ELLIPSIS
     'epi_reg --echospacing=0.000670 --fmap=fieldmap_phase_fslprepared.nii \
 --fmapmag=fieldmap_mag.nii --fmapmagbrain=fieldmap_mag_brain.nii --noclean \
 --pedir=y --epi=epi.nii --t1=T1.nii --t1brain=T1_brain.nii --out=epi2struct'
@@ -888,7 +895,7 @@ class EPIDeWarp(FSLCommand):
     >>> dewarp.inputs.mag_file = "magnitude.nii"
     >>> dewarp.inputs.dph_file = "phase.nii"
     >>> dewarp.inputs.output_type = "NIFTI_GZ"
-    >>> dewarp.cmdline # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> dewarp.cmdline # doctest: +ELLIPSIS
     'epidewarp.fsl --mag magnitude.nii --dph phase.nii --epi functional.nii \
 --esp 0.58 --exfdw .../exfdw.nii.gz --nocleanup --sigma 2 --tediff 2.46 \
 --tmpdir .../temp --vsm .../vsm.nii.gz'
@@ -981,7 +988,7 @@ class EddyCorrect(FSLCommand):
     >>> from nipype.interfaces.fsl import EddyCorrect
     >>> eddyc = EddyCorrect(in_file='diffusion.nii',
     ...                     out_file="diffusion_edc.nii", ref_num=0)
-    >>> eddyc.cmdline # doctest: +ALLOW_UNICODE
+    >>> eddyc.cmdline
     'eddy_correct diffusion.nii diffusion_edc.nii 0'
 
     """
