@@ -156,7 +156,7 @@ class RegAladin(NiftyRegCommand):
     >>> node.inputs.flo_file = 'im2.nii'
     >>> node.inputs.rmask_file = 'mask.nii'
     >>> node.inputs.omp_core_val = 4
-    >>> node.cmdline  # doctest: +ALLOW_UNICODE
+    >>> node.cmdline
     'reg_aladin -aff im2_aff.txt -flo im2.nii -omp 4 -ref im1.nii \
 -res im2_res.nii.gz -rmask mask.nii'
 
@@ -367,7 +367,7 @@ class RegF3D(NiftyRegCommand):
     >>> node.inputs.flo_file = 'im2.nii'
     >>> node.inputs.rmask_file = 'mask.nii'
     >>> node.inputs.omp_core_val = 4
-    >>> node.cmdline  # doctest: +ALLOW_UNICODE
+    >>> node.cmdline
     'reg_f3d -cpp im2_cpp.nii.gz -flo im2.nii -omp 4 -ref im1.nii \
 -res im2_res.nii.gz -rmask mask.nii'
 
