@@ -169,31 +169,31 @@ scaled)
     >>> # Test sqrt operation
     >>> unary_sqrt = copy.deepcopy(unary)
     >>> unary_sqrt.inputs.operation = 'sqrt'
-    >>> unary_sqrt.cmdline  # doctest: +ALLOW_UNICODE
+    >>> unary_sqrt.cmdline
     'seg_maths im1.nii -sqrt -odt float im1_sqrt.nii'
     >>> unary_sqrt.run()  # doctest: +SKIP
     >>> # Test sqrt operation
     >>> unary_abs = copy.deepcopy(unary)
     >>> unary_abs.inputs.operation = 'abs'
-    >>> unary_abs.cmdline  # doctest: +ALLOW_UNICODE
+    >>> unary_abs.cmdline
     'seg_maths im1.nii -abs -odt float im1_abs.nii'
     >>> unary_abs.run()  # doctest: +SKIP
     >>> # Test bin operation
     >>> unary_bin = copy.deepcopy(unary)
     >>> unary_bin.inputs.operation = 'bin'
-    >>> unary_bin.cmdline  # doctest: +ALLOW_UNICODE
+    >>> unary_bin.cmdline
     'seg_maths im1.nii -bin -odt float im1_bin.nii'
     >>> unary_bin.run()  # doctest: +SKIP
     >>> # Test otsu operation
     >>> unary_otsu = copy.deepcopy(unary)
     >>> unary_otsu.inputs.operation = 'otsu'
-    >>> unary_otsu.cmdline  # doctest: +ALLOW_UNICODE
+    >>> unary_otsu.cmdline
     'seg_maths im1.nii -otsu -odt float im1_otsu.nii'
     >>> unary_otsu.run()  # doctest: +SKIP
     >>> # Test isnan operation
     >>> unary_isnan = copy.deepcopy(unary)
     >>> unary_isnan.inputs.operation = 'isnan'
-    >>> unary_isnan.cmdline  # doctest: +ALLOW_UNICODE
+    >>> unary_isnan.cmdline
     'seg_maths im1.nii -isnan -odt float im1_isnan.nii'
     >>> unary_isnan.run()  # doctest: +SKIP
 
@@ -302,28 +302,28 @@ separate time points
     >>> binary_sub = copy.deepcopy(binary)
     >>> binary_sub.inputs.operation = 'sub'
     >>> binary_sub.inputs.operand_file = 'im2.nii'
-    >>> binary_sub.cmdline  # doctest: +ALLOW_UNICODE
+    >>> binary_sub.cmdline
     'seg_maths im1.nii -sub im2.nii -odt float im1_sub.nii'
     >>> binary_sub.run()  # doctest: +SKIP
     >>> # Test mul operation
     >>> binary_mul = copy.deepcopy(binary)
     >>> binary_mul.inputs.operation = 'mul'
     >>> binary_mul.inputs.operand_value = 2.0
-    >>> binary_mul.cmdline  # doctest: +ALLOW_UNICODE
+    >>> binary_mul.cmdline
     'seg_maths im1.nii -mul 2.00000000 -odt float im1_mul.nii'
     >>> binary_mul.run()  # doctest: +SKIP
     >>> # Test llsnorm operation
     >>> binary_llsnorm = copy.deepcopy(binary)
     >>> binary_llsnorm.inputs.operation = 'llsnorm'
     >>> binary_llsnorm.inputs.operand_file = 'im2.nii'
-    >>> binary_llsnorm.cmdline  # doctest: +ALLOW_UNICODE
+    >>> binary_llsnorm.cmdline
     'seg_maths im1.nii -llsnorm im2.nii -odt float im1_llsnorm.nii'
     >>> binary_llsnorm.run()  # doctest: +SKIP
     >>> # Test splitinter operation
     >>> binary_splitinter = copy.deepcopy(binary)
     >>> binary_splitinter.inputs.operation = 'splitinter'
     >>> binary_splitinter.inputs.operand_str = 'z'
-    >>> binary_splitinter.cmdline  # doctest: +ALLOW_UNICODE
+    >>> binary_splitinter.cmdline
     'seg_maths im1.nii -splitinter z -odt float im1_splitinter.nii'
     >>> binary_splitinter.run()  # doctest: +SKIP
 
@@ -419,21 +419,21 @@ class BinaryMathsInteger(MathsCommand):
     >>> binaryi_dil = copy.deepcopy(binaryi)
     >>> binaryi_dil.inputs.operation = 'dil'
     >>> binaryi_dil.inputs.operand_value = 2
-    >>> binaryi_dil.cmdline  # doctest: +ALLOW_UNICODE
+    >>> binaryi_dil.cmdline
     'seg_maths im1.nii -dil 2 -odt float im1_dil.nii'
     >>> binaryi_dil.run()  # doctest: +SKIP
     >>> # Test dil operation
     >>> binaryi_ero = copy.deepcopy(binaryi)
     >>> binaryi_ero.inputs.operation = 'ero'
     >>> binaryi_ero.inputs.operand_value = 1
-    >>> binaryi_ero.cmdline  # doctest: +ALLOW_UNICODE
+    >>> binaryi_ero.cmdline
     'seg_maths im1.nii -ero 1 -odt float im1_ero.nii'
     >>> binaryi_ero.run()  # doctest: +SKIP
     >>> # Test pad operation
     >>> binaryi_pad = copy.deepcopy(binaryi)
     >>> binaryi_pad.inputs.operation = 'pad'
     >>> binaryi_pad.inputs.operand_value = 4
-    >>> binaryi_pad.cmdline  # doctest: +ALLOW_UNICODE
+    >>> binaryi_pad.cmdline
     'seg_maths im1.nii -pad 4 -odt float im1_pad.nii'
     >>> binaryi_pad.run()  # doctest: +SKIP
 
@@ -512,7 +512,7 @@ percent outliers
     >>> tuple_lncc.inputs.operation = 'lncc'
     >>> tuple_lncc.inputs.operand_file1 = 'im2.nii'
     >>> tuple_lncc.inputs.operand_value2 = 2.0
-    >>> tuple_lncc.cmdline  # doctest: +ALLOW_UNICODE
+    >>> tuple_lncc.cmdline
     'seg_maths im1.nii -lncc im2.nii 2.00000000 -odt float im1_lncc.nii'
     >>> tuple_lncc.run()  # doctest: +SKIP
 
@@ -521,7 +521,7 @@ percent outliers
     >>> tuple_lssd.inputs.operation = 'lssd'
     >>> tuple_lssd.inputs.operand_file1 = 'im2.nii'
     >>> tuple_lssd.inputs.operand_value2 = 1.0
-    >>> tuple_lssd.cmdline  # doctest: +ALLOW_UNICODE
+    >>> tuple_lssd.cmdline
     'seg_maths im1.nii -lssd im2.nii 1.00000000 -odt float im1_lssd.nii'
     >>> tuple_lssd.run()  # doctest: +SKIP
 
@@ -530,7 +530,7 @@ percent outliers
     >>> tuple_lltsnorm.inputs.operation = 'lltsnorm'
     >>> tuple_lltsnorm.inputs.operand_file1 = 'im2.nii'
     >>> tuple_lltsnorm.inputs.operand_value2 = 0.01
-    >>> tuple_lltsnorm.cmdline  # doctest: +ALLOW_UNICODE
+    >>> tuple_lltsnorm.cmdline
     'seg_maths im1.nii -lltsnorm im2.nii 0.01000000 -odt float \
 im1_lltsnorm.nii'
     >>> tuple_lltsnorm.run()  # doctest: +SKIP
@@ -575,7 +575,7 @@ class Merge(MathsCommand):
     >>> node.inputs.merge_files = files
     >>> node.inputs.dimension = 2
     >>> node.inputs.output_datatype = 'float'
-    >>> node.cmdline  # doctest: +ALLOW_UNICODE
+    >>> node.cmdline
     'seg_maths im1.nii -merge 2 2 im2.nii im3.nii -odt float im1_merged.nii'
 
     """
