@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+from __future__ import print_function, division, unicode_literals, absolute_import
 
 from .debug import DebugPlugin
 from .linear import LinearPlugin
@@ -19,5 +20,4 @@ from .lsf import LSFPlugin
 from .slurm import SLURMPlugin
 from .slurmgraph import SLURMGraphPlugin
 
-from .callback_log import log_nodes_cb
 from . import  semaphore_singleton
