@@ -120,7 +120,7 @@ def create_resting_preproc(name='restpreproc', base_dir=None):
                         name='getthreshold')
     threshold_stddev = pe.Node(fsl.Threshold(), name='threshold')
     compcor = pe.Node(confounds.ACompCor(components_file="noise_components.txt",
-                                  use_regress_poly=False),
+                                         pre_filter=False),
                       name='compcor')
     remove_noise = pe.Node(fsl.FilterRegressor(filter_all=True),
                            name='remove_noise')
