@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
-from nipype.interfaces.utility import Function, IdentityInterface, Merge
-import nipype.pipeline.engine as pe  # pypeline engine
-from nipype.interfaces.freesurfer import *
+from __future__ import print_function, division, unicode_literals, absolute_import
+from ....interfaces.utility import Function, IdentityInterface, Merge
+from ....pipeline import engine as pe
+from ....interfaces.freesurfer import *
 from .utils import copy_file
 
 def copy_ltas(in_file, subjects_dir, subject_id, long_template):
